/* @@tag:xara-cn@@ DO NOT MODIFY THIS LINE
================================XARAHEADERSTART===========================

               XPFilter, an example plugin filter for XaraLX
                    Copyright (C) 1993-2006 Xara Group Ltd.
       Copyright on certain contributions may be held in joint with their
              respective authors. See AUTHORS file for details.

LICENSE TO USE AND MODIFY SOFTWARE
----------------------------------

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

    * Redistributions of source code must retain the above copyright notice,
      this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright notice,
      this list of conditions and the following disclaimer in the documentation
      and/or other materials provided with the distribution.
    * Neither the name of the Xara Group Ltd. nor the names of its contributors
      may be used to endorse or promote products derived from this software
      without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

MARKS
-----

Xara, Xara LX, Xara X, Xara X/Xtreme, Xara Xtreme, the Xtreme and Xara
designs are registered or unregistered trademarks, design-marks, and/or
service marks of Xara Group Ltd. All rights in these marks are reserved.

      Xara Group Ltd, Gaddesden Place, Hemel Hempstead, HP2 6EX, UK.
                        http://www.xara.com/

=================================XARAHEADEREND============================
*/
// stdfilter.cpp : This file implements a simple example filter to show how it's done
//

#include "xpfilter.h"


bool DoPrepareExportInternal(const wxString& sFileName, const wxString& sXMLFileName)
{
	// This should read and write the config XML to sXMLFileName
	// This filter doesn't actually use any so simply write the default XML

	// Open the XML file for writing
	wxFile OutFile;
	if (!OutFile.Create(sXMLFileName, true))
	{
		ReportError(_T("Open XML file failed"));
		// Set an appropriate error here
		return(false);
	}

	OutFile.Write(_T("<XPFilterConfig/>\n"));
	OutFile.Close();

	return true;
}


bool DoExportInternal(const wxString& sFileName, const wxString& sXMLFileName)
{
	// Open the output file for writing
	wxFile OutFile;
	if (!OutFile.Create(sFileName, true))
	{
		ReportError(_T("Open output file failed"));
		// Set an appropriate error here
		return(false);
	}

	wxFile StdInFile;
	StdInFile.Attach(wxFile::fd_stdin);

	wxFileOffset InFileLen = 400*1024;

	char Buffer[4096];
	size_t BufSize = 4096;
	size_t NumRead = 4096;
	wxFileOffset TotalWritten = 0;

	do
	{
		NumRead = StdInFile.Read(Buffer, BufSize);
		if (NumRead > 0)
		{
			size_t NumWritten = OutFile.Write(Buffer, NumRead);
			if (NumWritten != NumRead)
			{
				ReportError(_T("Failed to write all the data"));
				// Set an appropriate error here
				return(false);
			}
			TotalWritten += NumWritten;
			ReportProgress((TotalWritten * 100) / InFileLen);
		}
	}
	while(NumRead > 0);

	OutFile.Close();

	return true;
}


bool DoCanImportInternal(const wxString& sFileName)
{
	// This needs to look at the file and write the compatibility value to stdout

	int HowCompatible = 1;
	wxPrintf(_T("%d\n"), HowCompatible);

	return true;
}


bool DoImportInternal(const wxString& sFileName)
{
	// Open the input file for reading
	wxFile InFile(sFileName, wxFile::read);

	// If we failed to open the file then return an error
	if (!InFile.IsOpened())
	{
		// Set an appropriate error here
		return(false);
	}

	wxFileOffset InFileLen = InFile.Length();

	// Copy the data directly from InFile to stdout
	wxFile StdOutFile;
	StdOutFile.Attach(wxFile::fd_stdout);

	char Buffer[4096];
	size_t BufSize = 4096;
	size_t NumRead = 4096;
	wxFileOffset TotalWritten = 0;

	do
	{
		NumRead = InFile.Read(Buffer, BufSize);
		if (NumRead > 0)
		{
			size_t NumWritten = StdOutFile.Write(Buffer, NumRead);
			if (NumWritten != NumRead)
			{
				ReportError(_T("Failed to write all the data"));
				// Set an appropriate error here
				return(false);
			}
			TotalWritten += NumWritten;
			ReportProgress((TotalWritten * 100) / InFileLen);
		}
	}
	while(NumRead > 0);

	InFile.Close();

	return true;
}
