/* @@tag:xara-cn@@ DO NOT MODIFY THIS LINE
================================XARAHEADERSTART===========================

               XPFilter, an example plugin filter for XaraLX
                    Copyright (C) 1993-2006 Xara Group Ltd.
       Copyright on certain contributions may be held in joint with their
              respective authors. See AUTHORS file for details.

LICENSE TO USE AND MODIFY SOFTWARE
----------------------------------

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

    * Redistributions of source code must retain the above copyright notice,
      this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright notice,
      this list of conditions and the following disclaimer in the documentation
      and/or other materials provided with the distribution.
    * Neither the name of the Xara Group Ltd. nor the names of its contributors
      may be used to endorse or promote products derived from this software
      without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

MARKS
-----

Xara, Xara LX, Xara X, Xara X/Xtreme, Xara Xtreme, the Xtreme and Xara
designs are registered or unregistered trademarks, design-marks, and/or
service marks of Xara Group Ltd. All rights in these marks are reserved.

      Xara Group Ltd, Gaddesden Place, Hemel Hempstead, HP2 6EX, UK.
                        http://www.xara.com/

=================================XARAHEADEREND============================
*/
// xarlibfilter.cpp : This file implements a simple example filter to show how it's done
//

#include "xpfilter.h"

WX_DECLARE_HASH_MAP(UINT32, UINT32, wxIntegerHash, wxIntegerEqual, MapTagToUINT32);

class ExportData
{
public:
	MapTagToUINT32 m_RecordMap;
};

bool DoPrepareExportInternal(const wxString& sFileName, const wxString& sXMLFileName)
{
	// This should read and write the config XML to sXMLFileName
	// This filter doesn't actually use any so simply write the default XML



	return true;
}

BOOL HandleRecord(void* pMagic, CXaraFileRecord* pRecord)
{
	ExportData* pData = (ExportData*)pMagic;

	MapTagToUINT32::iterator iter;

	// Get the Tag of the record
	UINT32 Tag = pRecord->GetTag();

//	TRACE(_T("HandleRecord Tag = %d"), Tag);

	// Look it up in the map
	iter = pData->m_RecordMap.find(Tag);
	if (iter == pData->m_RecordMap.end())
	{
		// Not in the map so add a new item for this tag with a count of 1
		pData->m_RecordMap.insert(MapTagToUINT32::value_type(Tag, 1));
	}
	else
	{
		// Found the tag so increment the count
		(iter->second)++;
	}

	return(TRUE);
}

bool DoExportInternal(CXarImport* pImporter, const wxString& sFileName, const wxString& sXMLFileName)
{
	// Firstly we set up our map for the stats generation
	ExportData MyData;

	// Set up our record handler function
	if (!pImporter->SetHandler(&MyData, ::HandleRecord))
	{
		fprintf(stderr, "SetHandler failed.\n");
		// Set an appropriate error here
		return(false);
	}

	// And do the import
	if (!pImporter->DoImport())
	{
		ReportError(_T("Failed to parse Xar data."));
		// Set an appropriate error here
		return(false);
	}
	// Open the output file for writing
	wxFile OutFile;
	if (!OutFile.Create(sFileName, true))
	{
		ReportError(_T("Failed to open output file."));
		// Set an appropriate error here
		return(false);
	}

	// Now write out the stats file
	MapTagToUINT32::iterator iter = MyData.m_RecordMap.begin();

	wxString sTemp;
	while (iter != MyData.m_RecordMap.end())
	{
		sTemp.Printf(_T("% 5d - % 5d\n"), (*iter).first, (*iter).second);
		if (!OutFile.Write(sTemp))
		{
			ReportError(_T("Failed to write to output file."));
			// Set an appropriate error here
			return(false);
		}
		++iter;
	}

	return true;
}

bool DoCanImportInternal(const wxString& sFileName)
{
	// This needs to look at the file and write the compatibility value to stdout

	int HowCompatible = 1;
	wxPrintf(_T("%d\n"), HowCompatible);

	return true;
}

bool DoImportInternal(CXarExport* pExporter, const wxString& sFileName)
{
	// Open the input file for reading
	wxFileInputStream InFile(sFileName);
	if (!InFile.IsOk())
	{
		// Set an appropriate error here
		return(false);
	}

	wxTextInputStream InText(InFile);

	BOOL ok = TRUE;

	// Create a CXaraFileRecord object for the document header record
	CXaraFileRecord Rec(TAG_FILEHEADER);
	ok = Rec.Init();
	if (ok) ok = Rec.WriteBuffer((BYTE*)"CXN",3);
	if (ok) ok = Rec.WriteUINT32(123);				// File size
	if (ok) ok = Rec.WriteUINT32(0);				// Native/Web link ID
	if (ok) ok = Rec.WriteUINT32(0);				// Precompression flags
	if (ok) ok = Rec.WriteASCII(_T("XPFStats"));	// Producer
	if (ok) ok = Rec.WriteASCII(_T("0.01"));		// Producer version
	if (ok) ok = Rec.WriteASCII(_T(""));			// Producer build
	if (ok) ok = pExporter->WriteRecord(&Rec);

	// If any part of the header writing fails then return our own specific error
	if (!ok)
	{
		// Set an appropriate error here
		return(false);
	}

	// From this point on the error handling becomes a bit thin

	// Write a layer
	ok = pExporter->WriteZeroSizedRecord(TAG_LAYER);
	ok = pExporter->WriteZeroSizedRecord(TAG_DOWN);

	ok = Rec.Reinit(TAG_LAYERDETAILS, -1);
	ok = Rec.WriteBYTE(13);
	ok = Rec.WriteUnicode(_T("Layer 1"));
	ok = pExporter->WriteRecord(&Rec);

	ok = Rec.Reinit(TAG_TEXT_STORY_SIMPLE, TAG_TEXT_STORY_SIMPLE_SIZE);
	ok = Rec.WriteCoord(DocCoord(36000, 720000));
	ok = Rec.WriteUINT32(0);
	ok = pExporter->WriteRecord(&Rec);

	ok = pExporter->WriteZeroSizedRecord(TAG_DOWN);

	ok = Rec.Reinit(TAG_LINECOLOUR_NONE, 0);
	ok = pExporter->WriteZeroSizedRecord(TAG_LINECOLOUR_NONE);

	ok = Rec.Reinit(TAG_FLATFILL_BLACK, 0);
	ok = pExporter->WriteZeroSizedRecord(TAG_FLATFILL_BLACK);

	// Loop through lines of file
	while (!InFile.Eof())
	{
		wxString Line = InText.ReadLine();
		size_t Count = Line.Length();
		
		ok = pExporter->WriteZeroSizedRecord(TAG_TEXT_LINE);
		ok = pExporter->WriteZeroSizedRecord(TAG_DOWN);

		if (Count > 0)
		{
			ok = Rec.Reinit(TAG_TEXT_STRING, -1);
			ok = Rec.WriteWCHARs(Line.wc_str(), Count);
			ok = pExporter->WriteRecord(&Rec);
		}

		ok = pExporter->WriteZeroSizedRecord(TAG_TEXT_EOL);
		ok = pExporter->WriteZeroSizedRecord(TAG_UP);
	}

	// End of the text story
	ok = pExporter->WriteZeroSizedRecord(TAG_UP);

	// End of the layer
	ok = pExporter->WriteZeroSizedRecord(TAG_UP);

	// Write the end of file record
	ok = Rec.Reinit(TAG_ENDOFFILE, 0);
	ok = pExporter->WriteZeroSizedRecord(TAG_ENDOFFILE);

	return true;
}
